package SPVM::Sys::Socket::In_addr_base;



1;

=head1 Name

SPVM::Sys::Socket::In_addr_base - Base Class of L<struct in_addr|https://linux.die.net/man/3/inet_network> family.

=head1 Description

Sys::Socket::In_addr_base class in L<SPVM> is the base class of L<struct in_addr|https://linux.die.net/man/3/inet_network> family.

=head1 Usage

  use Sys::Socket::In_addr_base;

=head1 Well Known Child Classes

=over 2

=item * L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr>

=item * L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr>

=back

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

